Documentation
¶
Overview ¶
Package algoutil provides shared helper functions for the algorithm subpackages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BitstringToPhase ¶
BitstringToPhase converts a binary fraction bitstring to a phase in [0, 1).
func IdentityMap ¶
IdentityMap returns a qubit mapping {0:0, 1:1, ..., n-1:n-1}.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.